using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.CMSSiteMapProvider;
using CMS.TreeEngine;
using CMS.SettingsProvider;
using CMS.CMSHelper;

public partial class CMSDesk_Content_ContentTree : System.Web.UI.UserControl
{
    private string mNodeTextTemplate = "##ICON####NODENAME##";
    private string mSelectedNodeTextTemplate = "##ICON####NODENAME##";
    private int mNodeId = 0;
    private int mExpandNodeId = 0;
    //private string mSiteName = null;
    private string mPath = "/";
    private string mBasePath = null;
    protected TreeSiteMapProvider mMapProvider = null;
    private int mMaxTreeNodes = 0;
    private string mMaxTreeNodeText = null;
    private string mPreferredCulture = null;


    /// <summary>
    /// Preferred tree culture
    /// </summary>
    public string PreferredCulture
    {
        get
        {
            if (mPreferredCulture == null)
            {
                mPreferredCulture = CMSContext.CurrentUser.PreferredCultureCode;
            }
            return mPreferredCulture;
        }
        set
        {
            mPreferredCulture = value;
        }
    }


    /// <summary>
    /// Template of the node text, use {0} to insert the original node text, {1} to insert the Node ID
    /// </summary>
    public string NodeTextTemplate
    {
        get
        {
            return mNodeTextTemplate;
        }
        set
        {
            mNodeTextTemplate = value;
        }
    }


    /// <summary>
    /// Template of the SelectedNode text, use {0} to insert the original SelectedNode text, {1} to insert the SelectedNode ID
    /// </summary>
    public string SelectedNodeTextTemplate
    {
        get
        {
            return mSelectedNodeTextTemplate;
        }
        set
        {
            mSelectedNodeTextTemplate = value;
        }
    }


    /// <summary>
    /// Gets or sets the current node ID
    /// </summary>
    public int NodeID
    {
        get
        {
            return mNodeId;
        }
        set
        {
            mNodeId = value;
        }
    }


    /// <summary>
    /// Gets or sets the node ID to expand
    /// </summary>
    public int ExpandNodeID
    {
        get
        {
            return mExpandNodeId;
        }
        set
        {
            mExpandNodeId = value;
        }
    }


    /// <summary>
    /// Site name to display
    /// </summary>
    public string SiteName
    {
        get
        {
            string siteName = ValidationHelper.GetString(ViewState["SiteName"], "");
            if ((siteName == "") && (CMSContext.CurrentSite != null))
            {
                siteName = CMSContext.CurrentSite.SiteName;
            }
            return siteName;
        }
        set
        {
            ViewState["SiteName"] = value;
            this.MapProvider.SiteName = value;
        }
    }


    /// <summary>
    /// Nodes selecting path
    /// </summary>
    public string Path
    {
        get
        {
            return mPath;
        }
        set
        {
            mPath = value;
            this.MapProvider.Path = value;
        }
    }


    /// <summary>
    /// Sitemap provider that the tree uses
    /// </summary>
    public TreeSiteMapProvider MapProvider
    {
        get
        {
            if (mMapProvider == null)
            {
                mMapProvider = new TreeSiteMapProvider();
                TreeProvider tree = new TreeProvider();
                if (CMSContext.ViewMode == ViewModeEnum.LiveSite)
                {
                    tree.SelectQueryName = "selecttree";
                }
                else
                {
                    tree.SelectQueryName = "selecttreeversions";
                }
                mMapProvider.TreeProvider = tree;
                mMapProvider.CultureCode = TreeProvider.ALL_CULTURES;
                mMapProvider.SiteName = this.SiteName;
                mMapProvider.BindNodeData = true;
                mMapProvider.OrderBy = "NodeOrder ASC, NodeName ASC, NodeAlias ASC";
                mMapProvider.SelectOnlyPublished = false;
                mMapProvider.CombineWithDefaultCulture = true;
                mMapProvider.Path = this.Path;
                mMapProvider.MaxRelativeLevel = 1;
                mMapProvider.MaxTreeNodes = this.MaxTreeNodes + 1;
            }
            return mMapProvider;
        }
    }


    /// <summary>
    /// Maximum number of tree nodes displayed within the tree
    /// </summary>
    public int MaxTreeNodes
    {
        get
        {
            if (mMaxTreeNodes <= 0)
            {
                mMaxTreeNodes = SettingsKeyProvider.GetIntValue(CMSContext.CurrentSite.SiteName + ".CMSMaxTreeNodes");
            }
            return mMaxTreeNodes;
        }
        set
        {
            mMaxTreeNodes = value;
            this.MapProvider.MaxTreeNodes = value + 1;
        }
    }


    /// <summary>
    /// Text to appear within the latest node when max tree nodes applied
    /// </summary>
    public string MaxTreeNodeText
    {
        get
        {
            if (mMaxTreeNodeText == null)
            {
                mMaxTreeNodeText = ResHelper.GetString("ContentTree.SeeListing");
            }
            return mMaxTreeNodeText;
        }
        set
        {
            mMaxTreeNodeText = value;
        }
    }


    /// <summary>
    /// Nodes to expand
    /// </summary>
    protected ArrayList expandNodes = new ArrayList();


    protected void Page_Load(object sender, EventArgs e)
    {
        mBasePath = Request.Url.LocalPath;

        this.treeElem.LineImagesFolder = "~/App_Themes/" + this.Page.Theme + "/Images/Tree";
        if (CultureHelper.IsUICultureRTL())
        {
            this.treeElem.LineImagesFolder += "/RTL";
        }
        this.treeElem.ImageSet = TreeViewImageSet.Custom;
        this.treeElem.ExpandImageToolTip = ResHelper.GetString("ContentTree.Expand");
        this.treeElem.CollapseImageToolTip = ResHelper.GetString("ContentTree.Collapse");

        if (!this.Page.IsCallback)
        {
            ReloadData();
        }
    }


    public void ReloadData()
    {
        try
        {
            MapProvider.ReloadData();

            // Expand current node parent
            if ((this.ExpandNodeID <= 0) && (this.NodeID > 0))
            {
                TreeProvider tree = new TreeProvider();
                CMS.TreeEngine.TreeNode node = tree.SelectSingleNode(this.NodeID, TreeProvider.ALL_CULTURES);
                if (node != null)
                {
                    this.ExpandNodeID = node.NodeParentID;
                }
            }

            // If expand node set, set the node to expand
            if (this.ExpandNodeID > 0)
            {
                // Get node list to expand
                expandNodes.Clear();
                //TreeSiteMapNode targetNode = MapProvider.GetNodeById(this.ExpandNodeID);
                TreeProvider tree = new TreeProvider();
                CMS.TreeEngine.TreeNode node = tree.SelectSingleNode(this.ExpandNodeID, TreeProvider.ALL_CULTURES);
                if (node != null)
                {
                    TreeSiteMapNode targetNode = MapProvider.GetNodeByAliasPath(node.NodeAliasPath);
                    if (targetNode != null)
                    {
                        int targetNodeId = (int)targetNode.NodeData["NodeID"];
                        expandNodes.Add(targetNodeId);
                        while (targetNode.ParentNode != null)
                        {
                            int targetParentNodeId = (int)((TreeSiteMapNode)targetNode.ParentNode).NodeData["NodeID"];
                            expandNodes.Add(targetParentNodeId);
                            targetNode = (TreeSiteMapNode)targetNode.ParentNode;
                        }
                    }
                }
            }

            this.treeElem.Nodes.Clear();
            // Add root node
            this.treeElem.Nodes.Add(CreateNode((TreeSiteMapNode)MapProvider.RootNode, 0));
        }
        catch (Exception ex)
        {
            this.lblError.Text = ResHelper.GetString("ContentTree.FailedLoad") + ": " + ex.Message;
            this.lblError.ToolTip = ex.StackTrace;
        }
    }


    protected void treeElem_TreeNodePopulate(object sender, TreeNodeEventArgs e)
    {
        e.Node.ChildNodes.Clear();
        e.Node.PopulateOnDemand = false;

        int nodeId = ValidationHelper.GetInteger(e.Node.Value, 0);

        // check explore tree permission for current node
        bool userHasExploreTreePermission = (CMSContext.CurrentUser.IsAuthorizedPerTreeNode(nodeId, NodePermissionsEnum.ExploreTree) == AuthorizationResultEnum.Allowed) ? true : false;

        if (userHasExploreTreePermission)
        {
            //TreeSiteMapNode node = MapProvider.GetNodeById(nodeId);
            //SiteMapNodeCollection childNodes = node.ChildNodes;

            SiteMapNodeCollection childNodes = MapProvider.GetChildNodes(nodeId);
            int index = 0;
            foreach (TreeSiteMapNode childNode in childNodes)
            {
                int childNodeId = (int)childNode.NodeData["NodeID"];
                if (childNodeId != nodeId)
                {
                    System.Web.UI.WebControls.TreeNode newNode = CreateNode(childNode, index);
                    e.Node.ChildNodes.Add(newNode);
                    index++;
                }
            }
        }
        else
        {
            // add 'access denied node'
            System.Web.UI.WebControls.TreeNode tempNode = new System.Web.UI.WebControls.TreeNode();
            tempNode.Text = ResHelper.GetString("ContentTree.ExploreChildsDenied");
            tempNode.NavigateUrl = mBasePath + "#";
            e.Node.ChildNodes.Add(tempNode);
        }
    }


    protected System.Web.UI.WebControls.TreeNode CreateNode(TreeSiteMapNode sourceNode, int index)
    {
        System.Web.UI.WebControls.TreeNode newNode = new System.Web.UI.WebControls.TreeNode();
        int sourceNodeId = (int)sourceNode.NodeData["NodeID"];
            
        if (index < this.MaxTreeNodes)
        {
            newNode.Value = sourceNodeId.ToString();
            newNode.NavigateUrl = mBasePath + "#";

            int classId = ValidationHelper.GetInteger(sourceNode.NodeData["NodeClassID"], 0);
            DataClassInfo ci = DataClassInfoProvider.GetDataClass(classId);
            if (ci == null)
            {
                throw new Exception("[ContentTree.CreateNode]: Node class not found.");
            }

            string className = ci.ClassName;
            string imageUrl = ResolveUrl("~/App_Themes/" + this.Page.Theme + "/Images/CMSDesk/Icons/" + className.Replace(".", "_") + ".gif");
            string imageTag = "<img src=\"" + imageUrl + "\" alt=\"\" style=\"border:0px;vertical-align:middle;\" onclick=\"return false;\"/>";

            string nodeName = ValidationHelper.GetString(sourceNode.NodeData["DocumentName"], "");
            //if (sourceNode.TreeNode.DocumentCulture.ToLower() != this.PreferredCulture.ToLower())
            //{
            //    nodeName = sourceNode.TreeNode.NodeName;
            //}
            
            if (sourceNode.NodeData["NodeLinkedNodeID"] != DBNull.Value)
            {
                nodeName += CMSDeskPage.LINK_MARK;
            }

            if ((this.NodeID > 0) && (sourceNodeId == this.NodeID))
            {
                newNode.Text = SelectedNodeTextTemplate.Replace("##NODEID##", sourceNodeId.ToString()).Replace("##NODENAMEJAVA##", nodeName.Replace("'", "&apos;").Replace("\"", "&quot;")).Replace("##NODENAME##", nodeName).Replace("##ICON##", imageTag); //.DocumentName
            }
            else
            {
                newNode.Text = NodeTextTemplate.Replace("##NODEID##", sourceNodeId.ToString()).Replace("##NODENAMEJAVA##", nodeName.Replace("'", "&apos;").Replace("\"", "&quot;")).Replace("##NODENAME##", nodeName).Replace("##ICON##", imageTag); //.DocumentName
            }

            int childNodesCount = ValidationHelper.GetInteger(sourceNode.NodeData["NodeChildNodesCount"], 0);
            if (childNodesCount == 0)
            {
                newNode.PopulateOnDemand = false;
                newNode.Expanded = true;
            }
            else
            {
                if ((sourceNode.ChildNodes.Count > 0) || (!sourceNode.ChildNodesLoaded))
                {
                    newNode.PopulateOnDemand = true;
                }
            }

            string aliasPath = ValidationHelper.GetString(sourceNode.NodeData["NodeAliasPath"], "");
            if ((aliasPath.ToLower() != this.Path.ToLower()) && (!expandNodes.Contains(sourceNodeId)))
            {
                newNode.Expanded = false;
            }
            else
            {
                newNode.Expanded = true;
            }
        }
        else
        {
            string parentNodeId = ValidationHelper.GetString(sourceNode.NodeData["NodeParentID"], "");
            newNode.Value = sourceNodeId.ToString();
            newNode.Text = this.MaxTreeNodeText.Replace("##PARENTNODEID##", parentNodeId);
            newNode.NavigateUrl = "#";
        }

        return newNode;
    }
}
