using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.GlobalHelper;
using CMS.DataEngine;
using CMS.SiteProvider;
using CMS.Ecommerce;
using CMS.CMSHelper;

public partial class CMSDesk_Tools_Ecommerce_Configuration_OrderStatus_OrderStatus_Edit : CMSDeskPage
{
    protected int orderStatusId = 0;

    protected void Page_Load(object sender, EventArgs e)
    {
        // check 'EcommerceRead' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "ConfigurationRead"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "ConfigurationRead");
        }

        rfvStatusDisplayName.ErrorMessage = ResHelper.GetString("OrderStatus_Edit.ErrorDisplayName");
        rfvStatusName.ErrorMessage = ResHelper.GetString("OrderStatus_Edit.ErrorCodeName");

        // control initializations				
        lblStatusEnabled.Text = ResHelper.GetString("OrderStatus_Edit.StatusEnabledLabel");
        lblStatusDisplayName.Text = ResHelper.GetString("OrderStatus_Edit.StatusDisplayNameLabel");
        lblStatusName.Text = ResHelper.GetString("OrderStatus_Edit.StatusNameLabel");
        lblStatusColor.Text = ResHelper.GetString("OrderStatus_Edit.StatusColor");
        clrPicker.SupportFolder = "~/CMSAdminControls/ColorPicker";        

        btnOK.Text = ResHelper.GetString("General.OK");

        string currentOrderStatus = ResHelper.GetString("OrderStatus_Edit.NewItemCaption");

        // get order status id from querystring		
        orderStatusId = ValidationHelper.GetInteger(Request.QueryString["orderStatusId"], 0);
        if (orderStatusId > 0)
        {
            OrderStatusInfo orderStatusObj = OrderStatusInfoProvider.GetOrderStatusInfo(orderStatusId);
            if (orderStatusObj != null)
            {
                currentOrderStatus = ResHelper.LocalizeString(orderStatusObj.StatusDisplayName);

                // fill editing form
                if (!IsPostBack)
                {
                    LoadData(orderStatusObj);

                    // show that the orderStatus was created or updated successfully
                    if (ValidationHelper.GetString(Request.QueryString["saved"], "") == "1")
                    {
                        lblInfo.Visible = true;
                        lblInfo.Text = ResHelper.GetString("General.ChangesSaved");
                    }
                }
            }

            PageTitle.TitleText = ResHelper.GetString("OrderStatus_Edit.HeaderCaption");
            PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Ecommerce/Configuration/OrderStatus/status.gif";
        }
        else
        {
            PageTitle.TitleText = ResHelper.GetString("OrderStatus_Edit.NewItemCaption");
            PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Tools/Ecommerce/Configuration/OrderStatus/newstatus.gif";
        }

        // initializes page title control		
        string[,] pageTitleTabs = new string[2, 3];
        pageTitleTabs[0, 0] = ResHelper.GetString("OrderStatus_Edit.ItemListLink");
        pageTitleTabs[0, 1] = "~/CMSDesk/Tools/Ecommerce/Configuration/OrderStatus/OrderStatus_List.aspx";
        pageTitleTabs[0, 2] = "";
        pageTitleTabs[1, 0] = currentOrderStatus;
        pageTitleTabs[1, 1] = "";
        pageTitleTabs[1, 2] = "";
        PageTitle.Breadcrumbs = pageTitleTabs;
    }


    /// <summary>
    /// Load data of editing orderStatus.
    /// </summary>
    /// <param name="orderStatusObj">OrderStatus object.</param>
    protected void LoadData(OrderStatusInfo orderStatusObj)
    {
        chkStatusEnabled.Checked = orderStatusObj.StatusEnabled;
        txtStatusDisplayName.Text = orderStatusObj.StatusDisplayName;
        txtStatusName.Text = orderStatusObj.StatusName;
        clrPicker.SelectedColor = orderStatusObj.StatusColor;
    }

    /// <summary>
    /// Sets data to database.
    /// </summary>
    protected void btnOK_Click(object sender, EventArgs e)
    {
        // check 'ConfigurationModify' permission
        if (!CMSContext.CurrentUser.IsAuthorizedPerResource("CMS.Ecommerce", "ConfigurationModify"))
        {
            CMSDeskPage.RedirectToAccessDenied("CMS.Ecommerce", "ConfigurationModify");
        }

        string errorMessage = new Validator()
            .NotEmpty(txtStatusName.Text, ResHelper.GetString("OrderStatus_Edit.ErrorCodeName"))
            .NotEmpty(txtStatusDisplayName.Text, ResHelper.GetString("OrderStatus_Edit.ErrorDisplayName")).Result;

        if (!ValidationHelper.IsCodeName(txtStatusName.Text))
        {
            errorMessage = ResHelper.GetString("General.ErrorCodeNameInIdentificatorFormat");
        }

        if (errorMessage == "")
        {
            OrderStatusInfo orderStatusObj = OrderStatusInfoProvider.GetOrderStatusInfo(txtStatusName.Text);

			// if currencyName value is unique														
            if ((orderStatusObj == null) || (orderStatusObj.StatusID == orderStatusId))
            {
                // if currencyName value is unique -> determine whether it is update or insert 
                if ((orderStatusObj == null))
                {
                    // get CurrencyInfo object by primary key
                    orderStatusObj = OrderStatusInfoProvider.GetOrderStatusInfo(orderStatusId);
                    if (orderStatusObj == null)
                    {
                        // create new item -> insert
                        orderStatusObj = new OrderStatusInfo();

                    }
                }

                orderStatusObj.StatusEnabled = chkStatusEnabled.Checked;
                orderStatusObj.StatusDisplayName = txtStatusDisplayName.Text.Trim();
                orderStatusObj.StatusName = txtStatusName.Text.Trim();
                if (orderStatusObj.StatusOrder == 0)
                {
                    orderStatusObj.StatusOrder = OrderStatusInfoProvider.GetLastStatusOrder() + 1;
                }
                orderStatusObj.StatusColor = clrPicker.SelectedColor;

                OrderStatusInfoProvider.SetOrderStatusInfo(orderStatusObj);

                Response.Redirect("OrderStatus_Edit.aspx?orderStatusId=" + Convert.ToString(orderStatusObj.StatusID) + "&saved=1");
            }
            else
            {
                lblError.Visible = true;
                lblError.Text = ResHelper.GetString("OrderStatus_Edit.OrderStatusExist");
            }

        }
        else
        {
            lblError.Visible = true;
            lblError.Text = errorMessage;
        }
    }
}
