using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.PortalControls;
using CMS.GlobalHelper;
using CMS.TreeEngine;
using CMS.CMSHelper;

public partial class CMSWebParts_Search_cmssearchboxl : CMSAbstractWebPart
{
    /// <summary>Result page url</summary>
    protected string mResultPageUrl = "";


    #region "Public properties"

    /// <summary>
    /// Show image button instead of regular button?
    /// </summary>
    public bool ShowImageButton
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("ShowImageButton"), false);
        }
        set
        {
            this.SetValue("ShowImageButton", value);
            btnGo.Visible = !value;
            btnImageButton.Visible = value;
        }
    }


    /// <summary>
    /// Image button URL
    /// </summary>
    public string ImageUrl
    {
        get
        {
            return ResolveUrl(ValidationHelper.GetString(this.GetValue("ImageUrl"), btnImageButton.ImageUrl));
        }
        set
        {
            this.SetValue("ImageUrl", value);
            btnImageButton.ImageUrl = value;
        }
    }


    /// <summary>
    /// Show search label
    /// </summary>
    public bool ShowSearchLabel
    {
        get
        {
            return ValidationHelper.GetBoolean(this.GetValue("ShowSearchLabel"), this.lblSearch.Visible);
        }
        set
        {
            this.SetValue("ShowSearchLabel", value);
            this.lblSearch.Visible = value;
        }
    }


    /// <summary>
    /// Search label text
    /// </summary>
    public string SearchLabelText
    {
        get
        {
            return DataHelper.GetNotEmpty(this.GetValue("SearchLabelText"), ResHelper.LocalizeString("{$WebPart.SearchBox.Label$}"));
        }
        set
        {
            this.SetValue("SearchLabelText", value);
            this.lblSearch.Text = value;
        }
    }


    /// <summary>
    /// Search button text
    /// </summary>
    public string SearchButtonText
    {
        get
        {
            return DataHelper.GetNotEmpty(this.GetValue("SearchButtonText"), ResHelper.LocalizeString("{$WebPart.SearchBox.Button$}"));
        }
        set
        {
            this.SetValue("SearchButtonText", value);
            this.btnGo.Text = value;
        }
    }


    /// <summary>
    /// Search label Css class
    /// </summary>
    public string SearchLabelCssClass
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("SearchLabelCssClass"), "");
        }
        set
        {
            this.SetValue("SearchLabelCssClass", value);
            this.lblSearch.CssClass = value;
        }
    }


    /// <summary>
    /// Search text box CSS class
    /// </summary>
    public string SearchTextboxCssClass
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("SearchTextboxCssClass"), "");
        }
        set
        {
            this.SetValue("SearchTextboxCssClass", value);
            this.txtWord.CssClass = value;
        }
    }


    /// <summary>
    /// Search button CSS class
    /// </summary>
    public string SearchButtonCssClass
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("SearchButtonCssClass"), "");
        }
        set
        {
            this.SetValue("SearchButtonCssClass", value);
            this.btnGo.CssClass = value;
            this.btnImageButton.CssClass = value;
        }
    }


    /// <summary>
    /// Search results page URL
    /// </summary>
    public string SearchResultsPageUrl
    {
        get
        {
            return ValidationHelper.GetString(this.GetValue("SearchResultsPageUrl"), "");
        }
        set
        {
            this.SetValue("SearchResultsPageUrl", value);
            this.mResultPageUrl = value;
        }
    }


    /// <summary>
    /// Skin ID
    /// </summary>
    public override string SkinID
    {
        get
        {
            return base.SkinID;
        }
        set
        {
            base.SkinID = value;

            // Set SkinID properties
            if (this.PageCycle < PageCycleEnum.Loaded)
            {
                this.lblSearch.SkinID = value;
                this.txtWord.SkinID = value;
                this.btnGo.SkinID = value;
                this.btnImageButton.SkinID = value;
            }
        }
    }

    #endregion


    /// <summary>
    /// Content loaded event handler
    /// </summary>
    public override void OnContentLoaded()
    {
 	    base.OnContentLoaded();
        SetupControl();
    }


    /// <summary>
    /// Initializes the control properties
    /// </summary>
    protected void SetupControl()
    {
        if ((this.PageManager.ViewMode == ViewModeEnum.Design) || (this.HideOnCurrentPage) || (!this.IsVisible))
        {
        }
        else
        {
            btnGo.Visible = !this.ShowImageButton;
            btnImageButton.Visible = this.ShowImageButton;
            if (btnGo.Visible)
            {
                this.pnlSearch.DefaultButton = btnGo.ID;
            }
            else
            {
                this.pnlSearch.DefaultButton = "";
            }

            btnImageButton.ImageUrl = this.ImageUrl;

            // Set text properties
            if ( this.ShowSearchLabel )
            {
                this.lblSearch.Text = this.SearchLabelText;
            }
            
            this.btnGo.Text = this.SearchButtonText;

            // Set SkinID properties
            if (!this.StandAlone && (this.PageCycle < PageCycleEnum.Loaded))
            {
                string skinId = this.SkinID;
                this.lblSearch.SkinID = skinId;
                this.txtWord.SkinID = skinId;
                this.btnGo.SkinID = skinId;
                this.btnImageButton.SkinID = skinId;
            }

            // Set class properties
            this.lblSearch.CssClass = this.SearchLabelCssClass;
            this.txtWord.CssClass = this.SearchTextboxCssClass;
            this.btnGo.CssClass = this.SearchButtonCssClass;
            this.btnImageButton.CssClass = this.SearchButtonCssClass;

            // Set result page
            this.mResultPageUrl = this.SearchResultsPageUrl;
        }
    }
    

    protected void btnGo_Click(object sender, EventArgs e)
    {
        Search();
    }


    protected void btnImageButton_Click(object sender, ImageClickEventArgs e)
    {
        Search();
    }


    /// <summary>
    /// Runs the search
    /// </summary>
    private void Search()
    {
        if (txtWord.Text != null && txtWord.Text != "")
        {
            if (mResultPageUrl.StartsWith("~"))
            {
                mResultPageUrl = ResolveUrl(mResultPageUrl);
            }
            this.Response.Redirect(mResultPageUrl + "?searchtext=" + txtWord.Text);
        }
    }

}
